#
# spec file for package python-lupa
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-lupa
Version:        2.0
Release:        1.4
Summary:        Python wrapper around Lua and LuaJIT
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/scoder/lupa
Source:         https://files.pythonhosted.org/packages/source/l/lupa/lupa-%{version}.tar.gz
# PATCH-FIX-UPSTREAM no-bundle.patch gh#scoder/lupa@19279acda1ad
Patch1:         no-bundle.patch
# PATCH-FIX-UPSTREAM noexcept.patch gh#scoder/lupa@fc0a1af99b74
Patch2:         noexcept.patch
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(lua)
Suggests:       lua
%if 0%{suse_version} >= 1550 || 0%{?sle_version} >= 150400
# Synchronized with archs where luajit is build
%ifnarch riscv64 ppc64 ppc64le s390x
BuildRequires:  pkgconfig(luajit)
%endif
Recommends:     luajit
# /suse_version
%endif
%python_subpackages

%description
Python wrapper around Lua and LuaJIT.

%prep
%autosetup -p1 -n lupa-%{version}

rm -rf third-party/

%build
export CFLAGS="-fno-strict-aliasing %{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
mv lupa/tests .
mv lupa lupa.hide
sed -i 's/lupa.tests/tests/g' tests/test.py
%pyunittest_arch discover -v

%files %{python_files}
%doc CHANGES.rst README.rst
%license LICENSE.txt
%{python_sitearch}/lupa
%{python_sitearch}/lupa-%{version}*-info

%changelog
* Tue Oct 17 2023 Daniel Garcia Moreno <daniel.garcia@suse.com>
- Add upstream patches to built with Cython 3.0.3:
  - Add no-bundle.patch gh#scoder/lupa@19279acda1ad
  - Add noexcept.patch gh#scoder/lupa@fc0a1af99b74
- Update to 2.0:
  - GH#217: Lua stack traces in Python exception messages are now
    reversed to match the order of Python stack traces.
  - GH#196: Lupa now ships separate extension modules built with Lua
    5.3, Lua 5.4, LuaJIT 2.0 and LuaJIT 2.1 beta. Note that this is
    build specific and may depend on the platform. A normal Python
    import cascade can be used.
  - GH#211: A new option max_memory allows to limit the memory usage
    of Lua code. (patch by Leo Developer)
  - GH#171: Python references in Lua are now more safely reference
    counted to prevent garbage collection glitches. (patch by
    Guilherme Dantas)
  - GH#146: Lua integers in Lua 5.3+ are converted from and to Python
    integers. (patch by Guilherme Dantas)
  - GH#180: The python.enumerate() function now returns indices as
    integers if supported by Lua. (patch by Guilherme Dantas)
  - GH#178: The Lua integer limits can be read from the module as
    LUA_MAXINTEGER and LUA_MININTEGER. (patch by Guilherme Dantas)
  - GH#174: Failures while calling the __index method in Lua during a
    table index lookup from Python could crash Python. (patch by
    Guilherme Dantas)
  - GH#137: Passing None as a dict key into table_from() crashed.
    (patch by Leo Developer)
  - GH#176: A new function python.args(*args, **kwargs) was added to
    help with building Python argument tuples and keyword argument
    dicts for Python function calls from Lua code.
  - GH#177: Tables that are not sequences raise IndexError when
    unpacking them. Previously, non-sequential items were simply
    ignored.
  - GH#179: Resolve some C compiler warnings about signed/unsigned
    comparisons. (patch by Guilherme Dantas)
  - Built with Cython 0.29.34.
* Fri Aug  4 2023 Matej Cepl <mcepl@suse.com>
- Synchronize architectures where luajit is Required with those
  where it is build (riscv64 ppc64 ppc64le s390x).
* Sat Jun 10 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Sat Dec  3 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 1.14.1
  * Rebuild with Cython 0.29.32 to support Python 3.11.
* Tue Oct 18 2022 Sarah Kriesch <sarah.kriesch@opensuse.org>
- No upstream LuaJIT on s390x
* Thu Sep 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 1.13 (2022-03-01)
  * Bundled Lua source files were missing in the source distribution.
* Mon Feb 21 2022 Andreas Schneider <asn@cryptomilk.org>
- Fix BR for luajit (Leap 15.3 only offers moonjit)
* Mon Feb 21 2022 Andreas Schneider <asn@cryptomilk.org>
- Skip building for python2
* Wed Dec 29 2021 Matej Cepl <mcepl@suse.com>
- Adjust BuildRequires for lua
* Sun Dec 12 2021 Ben Greiner <code@bnavigator.de>
- Update to 1.10
  * GH#147: Lua 5.4 is supported. (patch by Russel Davis)
  * The runtime version of the Lua library as a tuple (e.g. (5,3))
    is provided via lupa.LUA_VERSION and LuaRuntime.lua_version.
  * The Lua implementation name and version string is provided as
    LuaRuntime.lua_implementation.
  * setup.py accepts new command line arguments --lua-lib and
  - -lua-includes to specify the
  * Use Lua 5.4.3 in binary wheels and as bundled Lua.
  * Built with Cython 0.29.24 to support Python 3.9.
- Also successfully builds and tests on python310
- Update to pkgconfig(lua5.4)
* Thu Jul  1 2021 Andreas Schwab <schwab@suse.de>
- Force use of lua5.1, lua5.4 is not supported
* Tue May 25 2021 pgajdos@suse.com
- %%check: use %%pyunittest_arch rpm macro
* Thu Jan  7 2021 Matej Cepl <mcepl@suse.com>
- Remove third-party/ bundled application, use the system ones
  (bsc#1167557).
* Sat Mar 21 2020 Andreas Schwab <schwab@suse.de>
- No LuaJIT on riscv64
* Thu Mar  5 2020 pgajdos@suse.com
- version update to 1.9
  * Build against Lua 5.3 if available.
  * GH#129: Fix Lua module loading in Python 3.x.
  * GH#126: Fix build on Linux systems that install Lua as "lua52" package.
* Tue Dec 10 2019 Matej Cepl <mcepl@suse.com>
- Use pkgconf instead of directly defining required development
  packages.
* Tue Dec 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fix dependency on the luajit to pull any implementation
* Sat Feb 16 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.8
